<?php
/*
Plugin Name: Live Flickr comment Importer
Plugin URI: http://www.sanisoft.com/blog/wordpress-plugin-live-flickr-comment-importer/
Description: Add Flickr comments to your blog posts. <a href='options-general.php?page=live-flickr-comment-importer.php'>Configuration Page</a>
Author: Tarique Sani
Version: 1.0
Author URI: http://tariquesani.net/blog/
*/ 

/*  Copyright 2009  Tarique Sani  (email : tarique@sanisoft.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

require_once ('phpflickr/phpFlickr.php');

function live_flickr_comment_importer($content) {
	global $wpdb, $post;
	
	// Return if it is not a single post
	if(!is_single()) {
		return $content;
	}

	// return if the post has no Flickr photo ID
	$flickr_photo_id = get_post_meta($post->ID, 'flickr_photo_id', true);
	
	if(empty($flickr_photo_id)) {
		return $content;
	}		
	
	// Return if there is no Flickr API key
	$flickrapikey = get_option( 'flickrapikey' );
	if( !$flickrapikey ){
		return $content;
	}
		
	$f = new phpFlickr( $flickrapikey);
	
	$f->enableCache('fs', ABSPATH . 'wp-content/plugins/live-flickr-comment-importer/phpflickr/cache/');
	
	$comments = $f->photos_comments_getList($flickr_photo_id);
	
	//OK if there are comments then loop over them
	if(isset($comments['comments']['comment'])) {
		foreach( $comments['comments']['comment'] as $comment ) {
			
			// Is the comment already in the database? No! Add the damn thing!!
			if( null == $wpdb->get_var( "SELECT comment_ID FROM {$wpdb->comments} WHERE comment_author_url='{$comment['permalink']}'" ) ) {
				
				// Get Author info so that you can build an Avatar URL later
				$author = $f->people_getInfo($comment['author']);
				if ($author['iconserver'] > 0){
					// This is cheating - there should be a differnt field for it 
					$commentdata['comment_author_IP'] 		= $author['iconserver'] ."++". $author['id'];
				}
				
				$commentdata['comment_author']			= "Flickr: ".wp_specialchars($comment['authorname']);
				$commentdata['comment_author_email']	= 'nobody@flickr.com';
				$commentdata['comment_author_url'] 		= wp_specialchars($comment['permalink']);
				$commentdata['comment_content']			= addslashes( strip_tags($comment['_content']) );
				$commentdata['comment_type']			= '';
				$commentdata['comment_date']			= date("Y-m-d h:i:s", $comment['datecreate'] ) ;
				$commentdata['comment_date_gmt'] 		= gmdate("Y-m-d h:i:s", $comment['datecreate'] );			
				$commentdata['comment_post_ID'] 		= $post->ID;	
				$commentdata['user_ID']					= 0;
				$commentdata['comment_agent']     		= "Live Flickr Add Comment Agent";
				$commentdata['comment_approved'] 		= 1;
				$comment_ID = wp_insert_comment($commentdata);
			}
		}
	}
	
	return $content;
}

// All the blah functions to get the admin part going...
if ( ! function_exists('wp_nonce_field') ) {
	function lfci_nonce_field($action = -1) {
		return;	
	}
	$fci_nonce = -1;
} else {
	function lfci_nonce_field($action = -1) {
		return wp_nonce_field($action);
	}
	$fci_nonce = 'fci-update-key';
}

function lfci_config_page() {
	global $wpdb;
	if ( function_exists('add_submenu_page') )
		add_submenu_page('options-general.php', __('Live Flickr Comments'), __('Live Flickr Comments'), 'manage_options', __FILE__, 'lfci_conf');
}

function lfci_conf() {
	global $fci_nonce;
	if ( isset($_POST['submit']) ) {
		if ( function_exists('current_user_can') && !current_user_can('manage_options') )
			die(__('Cheatin&#8217; uh?'));

		check_admin_referer($fci_nonce);
		
		//Verify API key
		$f = new phpFlickr( $_POST[ 'flickrapikey' ] );
		
		if($f->test_echo() === false) {
			$invalid_key = true;
		} else {
			update_option( 'flickrapikey', $_POST[ 'flickrapikey' ] );
		}
	}
?>

<div class="wrap">
<h2><?php _e('Live Flickr Comment Importer'); ?></h2>
	<p><?php _e( "If you use Flickr to host your photos this plugin will import the comments from your Flickr stream into your blog posts. Enter the a Flickr API key which you can get from <a href='http://www.flickr.com/services/api/key.gne'>http://www.flickr.com/services/api/key.gne</a> in the box below." );?></p>
<form action="" method="post" id="fci-conf" style="margin: auto; ">
<?php lfci_nonce_field($fci_nonce) ?>
<h3><label for="key"><?php _e('Flickr Api Key'); ?></label></h3>
<p><input id="url" name="flickrapikey" type="text" size="30" maxlength="300" value="<?php echo get_option('flickrapikey'); ?>" style="font-family: 'Courier New', Courier, mono; font-size: 1.5em;" /></p>
<?php if ( $invalid_key ) { ?>
	<p style="padding: .5em; background-color: #f33; color: #fff; font-weight: bold; width: 30em"><?php _e('That is not a valid Flickr API key'); ?></p>
<?php } ?>
	<p class="submit"><input type="submit" name="submit" value="<?php _e('Update API key &raquo;'); ?>" /></p>
</form>
<?php if ( !is_writeable(ABSPATH . 'wp-content/plugins/live-flickr-comment-importer/phpflickr/cache/') ) { ?>
	<p style="padding: .5em; background-color: #f33; color: #fff; font-weight: bold; width: 50em"><?php _e('WARNING: Your cache path '.ABSPATH . 'wp-content/plugins/live-flickr-comment-importer/phpflickr/cache/'.' is not writeable by the webserver. Please change permissions to make it writeable'); ?></p>
<?php } ?>

	<p><?php _e( "<strong>Usage and Restrictions</strong><br /><ul><li> Your posts must have a custom field called flickr_photo_id with the value as ID of the photo on Flickr whose comments you want to import in the post.<li>Flickr Photo ID is usually the last number in the URL of the photo page eg: In <a href='http://www.flickr.com/photos/tariquesani/4175454833/'>http://www.flickr.com/photos/tariquesani/4175454833/</a> - 4175454833 is the photo ID</li><li>See how to <a href='http://www.boosten.org/using-custom-fields-in-wordpress-posts/' >include a custom field in your post</a>.</li><li>Comments will be imported whenever someone visits the post</li></ul>" );?></p>

<p><?php _e( "Don't forget to visit my blog at <a href='http://tariquesani.net/blog/'>http://tariquesani.net/blog/</a>." ); ?>
</div>
<?php
}

// If the comment is from Flickr build the avatar from Flickr data
function get_flickr_avatar($avatar, $comment, $size) {
		if($comment->comment_author_email == 'nobody@flickr.com'){
			$tmp = explode("++",$comment->comment_author_IP);
			$avatar = "<img alt='' src='http://static.flickr.com/{$tmp[0]}/buddyicons/{$tmp[1]}.jpg' class='avatar avatar-{$size} photo' height='{$size}' width='{$size}' />";
		}		
		return $avatar;
}

add_filter( 'get_avatar','get_flickr_avatar', 1, 3 );
add_filter('the_content', 'live_flickr_comment_importer');
add_action('admin_menu', 'lfci_config_page');

?>
